Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManagerWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManagerWidget.cpp	(revision 84581)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManagerWidget.cpp	(revision 84582)
@@ -494,5 +494,5 @@
 
             /* Create Chooser-pane: */
-            m_pPaneChooser = new UIChooser(this);
+            m_pPaneChooser = new UIChooser(this, actionPool());
             if (m_pPaneChooser)
             {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooser.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooser.cpp	(revision 84581)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooser.cpp	(revision 84582)
@@ -24,10 +24,9 @@
 #include "UIChooserModel.h"
 #include "UIChooserView.h"
-#include "UIVirtualBoxManagerWidget.h"
-
-
-UIChooser::UIChooser(UIVirtualBoxManagerWidget *pParent)
+
+
+UIChooser::UIChooser(QWidget *pParent, UIActionPool *pActionPool)
     : QWidget(pParent)
-    , m_pManagerWidget(pParent)
+    , m_pActionPool(pActionPool)
     , m_pChooserModel(0)
     , m_pChooserView(0)
@@ -39,10 +38,4 @@
 {
     cleanup();
-}
-
-UIActionPool *UIChooser::actionPool() const
-{
-    AssertPtrReturn(managerWidget(), 0);
-    return managerWidget()->actionPool();
 }
 
@@ -205,5 +198,5 @@
 {
     /* Prepare Chooser-model: */
-    m_pChooserModel = new UIChooserModel(this);
+    m_pChooserModel = new UIChooserModel(this, actionPool());
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.cpp	(revision 84581)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.cpp	(revision 84582)
@@ -30,5 +30,4 @@
 
 /* GUI includes: */
-#include "UIChooser.h"
 #include "UIChooserItem.h"
 #include "UIChooserItemGroup.h"
@@ -91,5 +90,5 @@
 
         /* Return the parent: */
-        return QAccessible::queryAccessibleInterface(item()->model()->chooser()->view());
+        return QAccessible::queryAccessibleInterface(item()->model()->view());
     }
 
@@ -138,6 +137,6 @@
         const QSize   itemSize         = item()->size().toSize();
         const QPointF itemPosInScene   = item()->mapToScene(QPointF(0, 0));
-        const QPoint  itemPosInView    = item()->model()->chooser()->view()->mapFromScene(itemPosInScene);
-        const QPoint  itemPosInScreen  = item()->model()->chooser()->view()->mapToGlobal(itemPosInView);
+        const QPoint  itemPosInView    = item()->model()->view()->mapFromScene(itemPosInScene);
+        const QPoint  itemPosInScreen  = item()->model()->view()->mapToGlobal(itemPosInView);
         const QRect   itemRectInScreen = QRect(itemPosInScreen, itemSize);
         return itemRectInScreen;
@@ -345,9 +344,4 @@
     AssertMsg(pModel, ("Incorrect graphics scene parent set!"));
     return pModel;
-}
-
-UIActionPool *UIChooserItem::actionPool() const
-{
-    return model()->actionPool();
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h	(revision 84581)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h	(revision 84582)
@@ -108,6 +108,4 @@
         /** Returns model reference. */
         UIChooserModel *model() const;
-        /** Returns action-pool reference. */
-        UIActionPool *actionPool() const;
 
         /** Returns whether item is root. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 84581)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 84582)
@@ -57,7 +57,7 @@
 
 
-UIChooserModel:: UIChooserModel(UIChooser *pParent)
+UIChooserModel::UIChooserModel(UIChooser *pParent, UIActionPool *pActionPool)
     : UIChooserAbstractModel(pParent)
-    , m_pChooser(pParent)
+    , m_pActionPool(pActionPool)
     , m_pScene(0)
     , m_pMouseHandler(0)
@@ -98,12 +98,7 @@
 }
 
-UIChooser *UIChooserModel::chooser() const
-{
-    return m_pChooser;
-}
-
 UIActionPool *UIChooserModel::actionPool() const
 {
-    return chooser() ? chooser()->actionPool() : 0;
+    return m_pActionPool;
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooser.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooser.h	(revision 84581)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooser.h	(revision 84582)
@@ -32,5 +32,4 @@
 class UIChooserModel;
 class UIChooserView;
-class UIVirtualBoxManagerWidget;
 class UIVirtualMachineItem;
 
@@ -80,6 +79,7 @@
 public:
 
-    /** Constructs Chooser-pane passing @a pParent to the base-class. */
-    UIChooser(UIVirtualBoxManagerWidget *pParent);
+    /** Constructs Chooser-pane passing @a pParent to the base-class.
+      * @param  pActionPool  Brings the action-pool reference.  */
+    UIChooser(QWidget *pParent, UIActionPool *pActionPool);
     /** Destructs Chooser-pane. */
     virtual ~UIChooser() /* override */;
@@ -87,9 +87,6 @@
     /** @name General stuff.
       * @{ */
-        /** Returns the manager-widget reference. */
-        UIVirtualBoxManagerWidget *managerWidget() const { return m_pManagerWidget; }
-
         /** Returns the action-pool reference. */
-        UIActionPool *actionPool() const;
+        UIActionPool *actionPool() const { return m_pActionPool; }
 
         /** Return the Chooser-model instance. */
@@ -197,6 +194,6 @@
     /** @name General stuff.
       * @{ */
-        /** Holds the manager-widget reference. */
-        UIVirtualBoxManagerWidget *m_pManagerWidget;
+        /** Holds the action-pool reference. */
+        UIActionPool *m_pActionPool;
 
         /** Holds the Chooser-model instane. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h	(revision 84581)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h	(revision 84582)
@@ -99,5 +99,5 @@
 
     /** Constructs Chooser-model passing @a pParent to the base-class. */
-    UIChooserModel(UIChooser *pParent);
+    UIChooserModel(UIChooser *pParent, UIActionPool *pActionPool);
     /** Destructs Chooser-model. */
     virtual ~UIChooserModel() /* override */;
@@ -110,6 +110,4 @@
         virtual void deinit() /* override */;
 
-        /** Returns the Chooser reference. */
-        UIChooser *chooser() const;
         /** Returns the action-pool reference. */
         UIActionPool *actionPool() const;
@@ -381,6 +379,6 @@
     /** @name General stuff.
       * @{ */
-        /** Holds the Chooser reference. */
-        UIChooser *m_pChooser;
+        /** Holds the action-pool reference. */
+        UIActionPool *m_pActionPool;
 
         /** Holds the scene reference. */
